@@ -394,6 +394,9 @@ typedef enum _MEDIA_EVENT
     EVENT_DECODE_DDI_SETGPUPRIORITYVA,             //! event for Decode DDI SetGpuPriority
     EVENT_DECODE_FEATURE_DECODEMODE_REPORTVA,      //! event for Decode Feature Decode Mode Report
     EVENT_DECODE_INFO_PICTUREVA,                   //! event for Decode Picture Info VA
+    EVENT_DECODE_IP_ALIGNMENT,                     //! event for Decode IP Alignment
+    EVENT_ENCODE_IP_ALIGNMENT,                     //! event for Encode IP Alignment
+    EVENT_VPP_IP_ALIGNMENT,                        //! event for VPP IP Alignment
 } MEDIA_EVENT;
 
 typedef enum _MEDIA_EVENT_TYPE
@@ -550,6 +553,11 @@ typedef enum _MT_LOG_ID
     MT_MOS_MM_BIND_GPU_RESOURCE_VIRTUAL,
     MT_MOS_MM_UNBIND_GPU_RESOURCE_VIRTUAL,
     MT_ERR_CRITICAL_MESSAGE,
+    MT_MOS_ALLOCATE_MEMORY,
+    MT_MOS_DESTROY_MEMORY,
+    MT_MOS_MEMORY_NINJA_COUNTER,
+    MT_GPU_ALLOCATE_MEMORY,
+    MT_GPU_DESTROY_MEMORY,
     MT_LOG_ID_CP_BASE = 0x01000000,
     MT_CP_HAL_NOT_INITIALIZED,
     MT_CP_HAL_FAIL,
@@ -680,6 +688,7 @@ typedef enum _MT_LOG_ID
     MT_CP_DDI_RESOURCE_CREATE,
     MT_CP_DDI_OS_RESOURCE_INIT,
     MT_CP_DDI_FUNC_UNSUPPORTED,
+    MT_CP_DDI_LBDM_FALLBACK_SWDRM,
     MT_LOG_ID_VP_BASE = 0x02000000,
     MT_VP_CREATE,
     MT_VP_DESTROY,
@@ -708,8 +717,8 @@ typedef enum _MT_LOG_ID
     MT_VP_USERFEATURE_CTRL,
     MT_VP_FTR_REPORT,
     MT_VP_FEATURE_GRAPH_ID_BASE = 0x02000200,
-    MT_VP_FEATURE_GRAPH_CREATESWFILTERPIPE_START,
-    MT_VP_FEATURE_GRAPH_CREATESWFILTERPIPE_END,
+    MT_VP_FEATURE_GRAPH_EXECUTE_VPPIPELINE_START,
+    MT_VP_FEATURE_GRAPH_EXECUTE_VPPIPELINE_END,
     MT_VP_FEATURE_GRAPH_SETUPEXECUTESWFILTER_START,
     MT_VP_FEATURE_GRAPH_SETUPEXECUTESWFILTER_END,
     MT_VP_FEATURE_GRAPH_EXECUTEFILTER,
@@ -735,6 +744,18 @@ typedef enum _MT_LOG_ID
     MT_VP_FEATURE_GRAPH_SWFILTERS3D,
     MT_VP_FEATURE_GRAPH_SWFILTERSECURECOPY,
     MT_VP_FEATURE_GRAPH_SWFILTERVEBOXUPDATE,
+    MT_VP_FEATURE_GRAPH_SWFILTERSTD,
+    MT_VP_FEATURE_GRAPH_INPUTSWFILTER,
+    MT_VP_FEATURE_GRAPH_OUTPUTSWFILTER,
+    MT_VP_FEATURE_GRAPH_INPUT_SURFACE_INFO,
+    MT_VP_FEATURE_GRAPH_INTERMEIDATE_SURFACE_INFO,
+    MT_VP_FEATURE_GRAPH_OUTPUT_SURFACE_INFO,
+    MT_VP_FEATURE_GRAPH_SURFACE_ALLOCATIONHANDLE,
+    MT_VP_FEATURE_GRAPH_GET_RENDERTARGETTYPE,
+    MT_VP_FEATURE_GRAPH_SWFILTERSR,
+    MT_VP_FEATURE_GRAPH_FEATUREPIPE_REUSE,
+    MT_VP_FEATURE_GRAPH_EXECUTE_SINGLE_VPPIPELINE_START,
+    MT_VP_FEATURE_GRAPH_EXECUTE_SINGLE_VPPIPELINE_END,
     MT_VP_HAL_ID_BASE = 0x02000400,
     MT_VP_HAL_PIPELINE_ADAPTER,
     MT_VP_HAL_PIPELINE_ADAPTER_EXT_ENTRY,
@@ -769,6 +790,11 @@ typedef enum _MT_LOG_ID
     MT_VP_HAL_POLICY_FLITER_FTR_COMBINE,
     MT_VP_HAL_FC_UPDATE_COMP_PARAM,
     MT_VP_HAL_FC_GET_CURBE_STATE,
+    MT_VP_HAL_DESTROY_SURF,
+    MT_VP_HAL_MEMORY_FOOTPRINT_EXECUTION_ENTRY,
+    MT_VP_HAL_MEMORY_FOOTPRINT_EXECUTION_EXIT,
+    MT_VP_HAL_VEBOXNUM_CHECK,
+    MT_VP_HAL_VEBOXNUM_RESET,
     MT_VP_MHW_ID_BASE = 0x02002000,
     MT_VP_MHW_VE_SURFSTATE_INPUT,
     MT_VP_MHW_VE_SURFSTATE_OUT,
@@ -777,6 +803,7 @@ typedef enum _MT_LOG_ID
     MT_VP_MHW_VE_SURFSTATE_STMM,
     MT_VP_MHW_VE_SCALABILITY,
     MT_VP_MHW_VE_ADJUST_SURFPARAM,
+    MT_VP_MHW_CACHE_MOCS_TABLE,
     MT_VP_KERNEL_ID_BASE = 0x02003000,
     MT_VP_KERNEL_CSC,
     MT_VP_KERNEL_RULE,
@@ -798,7 +825,7 @@ typedef enum _MT_LOG_ID
 //!
 typedef enum _MT_PARAM_ID
 {
-    MT_PARAM_ID_BASE    = 0,
+    MT_PARAM_ID_BASE = 0,
     MT_ERROR_CODE,
     MT_COMPONENT,
     MT_SUB_COMPONENT,
@@ -852,6 +879,12 @@ typedef enum _MT_PARAM_ID
     MT_COMMAND_GPUVA,
     MT_FUNC_NAME,
     MT_FUNC_LINE,
+    MT_MEMORY_PTR,
+    MT_MEMORY_SIZE,
+    MT_MEMORY_INDEX,
+    MT_MEMORY_NINJA_START_COUNTER,
+    MT_MEMORY_NINJA_END_COUNTER,
+    MT_MEMORY_NINJA_IS_START,
     MT_PARAM_ID_MOS_BASE = 0x00001000,
     MT_MOS_STATUS,
     MT_MOS_GPU_NODE,
@@ -865,6 +898,12 @@ typedef enum _MT_PARAM_ID
     MT_MOS_SYNC_BUSYCTX,
     MT_MOS_SYNC_REQCTX,
     MT_MOS_MM_EXT_RESOURCE_NEED_MAKE_RESIDENT,
+    MT_SYNC_WAIT_LOOPCOUNTER,
+    MT_SYNC_CUR_FENCE_TAG,
+    MT_SYNC_LAST_FENCE_TAG,
+    MT_SYNC_WAIT_BEFORE_SYNC,
+    MT_SYNC_WAIT_MICROSECOND,
+    MT_SYNC_WAIT_RESULT,
     MT_PARAM_ID_CP_BASE  = 0x01000000,
     MT_CP_SESSION_TYPE,
     MT_CP_SESSION_MODE,
@@ -928,6 +967,8 @@ typedef enum _MT_PARAM_ID
     MT_VP_BLT_FDFBPARAM_FACECOUNT,
     MT_VP_BLT_FDFBPARAM_FBMAXFACECOUNT,
     MT_VP_BLT_SR_MODE,
+    MT_VP_BLT_SR_EU,
+    MT_VP_BLT_SR_GEN,
     MT_PARAM_ID_VP_HAL_BASE = 0x02000400,
     MT_VP_HAL_APO,
     MT_VP_HAL_PTR,
@@ -991,6 +1032,15 @@ typedef enum _MT_PARAM_ID
     MT_VP_HAL_MMCINUSE,
     MT_VP_HAL_FRC_MODE,
     MT_VP_HAL_CAPTURE_PIPE,
+    MT_VP_HAL_SURF_ALLOC_PARAM_PTR,
+    MT_VP_HAL_SURF_ALLOC_PARAM_MOS_SURF_PTR,
+    MT_VP_HAL_SURF_ALLOC_PARAM_IS_RES_OWNER,
+    MT_VP_HAL_SURF_ALLOC_PARAM_HANDLE,
+    MT_VP_HAL_SURF_ALLOC_PARAM_SIZE,
+    MT_VP_HAL_SURF_ALLOC_PARAM_NAME,
+    MT_VP_HAL_SURF_ALLOC_PARAM_PEAK_SIZE,
+    MT_VP_HAL_SURF_ALLOC_PARAM_TOTAL_SIZE,
+    MT_VP_HAL_VEBOX_NUMBER,
     MT_PARAM_ID_VP_FEATURE_GRAPH_BASE = 0x02001400,
     MT_VP_FEATURE_GRAPH_FILTER_SWFILTERPIPE_COUNT,
     MT_VP_FEATURE_GRAPH_FILTER_LAYERINDEXES_COUNT,
@@ -1058,10 +1108,42 @@ typedef enum _MT_PARAM_ID
     MT_VP_FEATURE_GRAPH_FILTER_ENABLES3D,
     MT_VP_FEATURE_GRAPH_FILTER_STEREOFORMAT,
     MT_VP_FEATURE_GRAPH_FILTER_VEBOXSTATECOPYNEEDED,
+    MT_VP_FEATURE_GRAPH_FILTER_STD_OUTPUT_ENABLE,
+    MT_VP_FEATURE_GRAPH_FILTER_STD_OUTPUT_TO_STDPARAM,
+    MT_VP_FEATURE_GRAPH_FILTER_STD_OUTPUT_TO_OUTPUT_SURFACE,
+    MT_VP_FEATURE_GRAPH_SURFACE_WIDTH,
+    MT_VP_FEATURE_GRAPH_SURFACE_HEIGHT,
+    MT_VP_FEATURE_GRAPH_SURFACE_PITCH,
+    MT_VP_FEATURE_GRAPH_SURFACE_COLORSPACE,
+    MT_VP_FEATURE_GRAPH_SURFACE_FORMAT,
+    MT_VP_FEATURE_GRAPH_SURFACE_RCSRC_LEFT,
+    MT_VP_FEATURE_GRAPH_SURFACE_RCSRC_TOP,
+    MT_VP_FEATURE_GRAPH_SURFACE_RCSRC_RIGHT,
+    MT_VP_FEATURE_GRAPH_SURFACE_RCSRC_BOTTOM,
+    MT_VP_FEATURE_GRAPH_SURFACE_RCDST_LEFT,
+    MT_VP_FEATURE_GRAPH_SURFACE_RCDST_TOP,
+    MT_VP_FEATURE_GRAPH_SURFACE_RCDST_RIGHT,
+    MT_VP_FEATURE_GRAPH_SURFACE_RCDST_BOTTOM,
+    MT_VP_FEATURE_GRAPH_RENDERTARGETTYPE,
+    MT_VP_FEATURE_GRAPH_FILTER_ESRMODE,
+    MT_VP_FEATURE_GRAPH_FILTER_SRMODEL,
+    MT_VP_FEATURE_GRAPH_FILTER_SRSTAGE,
+    MT_VP_FEATURE_GRAPH_FILTER_FRAMENUMBER,
+    MT_VP_FEATURE_GRAPH_FILTER_FIRSTFRAME,
+    MT_VP_FEATURE_GRAPH_FILTER_ENABLESR,
+    MT_VP_FEATURE_GRAPH_FILTER_FRAMEID,
+    MT_VP_FEATURE_GRAPH_FILTER_PIPEID,
+    MT_VP_FEATURE_GRAPH_FILTER_PIPELINEBYPASS,
     MT_PARAM_ID_VP_MHW_BASE = 0x02002000,
     MT_VP_MHW_VE_SCALABILITY_EN,
     MT_VP_MHW_VE_SCALABILITY_USE_SFC,
     MT_VP_MHW_VE_SCALABILITY_IDX,
+    MT_VP_MHW_CACHE_MEMORY_OBJECT_CONTROL_STATE,
+    MT_VP_MHW_CACHE_MEMORY_OBJECT_NAME,
+    MT_VP_MHW_CACHE_MEMORY_OBJECT_SURFACE_TYPE,
+    MT_VP_MHW_CACHE_MEMORY_OBJECT_SURFACE_WIDTH,
+    MT_VP_MHW_CACHE_MEMORY_OBJECT_SURFACE_HEIGHT,
+    MT_VP_MHW_CACHE_MEMORY_OBJECT_SURFACE_FORMAT,
     MT_PARAM_ID_VP_KERNEL_BASE = 0x02003000,
     MT_VP_KERNEL_CSPACE, 
     MT_VP_KERNEL_RULE_ID,
