@@ -1,27 +1,23 @@
 /*
+* Copyright (c) 2018-2022, Intel Corporation
 *
-* Copyright (c) Intel Corporation (2018 - 2019).
+* Permission is hereby granted, free of charge, to any person obtaining a
+* copy of this software and associated documentation files (the "Software"),
+* to deal in the Software without restriction, including without limitation
+* the rights to use, copy, modify, merge, publish, distribute, sublicense,
+* and/or sell copies of the Software, and to permit persons to whom the
+* Software is furnished to do so, subject to the following conditions:
 *
-* INTEL MAKES NO WARRANTY OF ANY KIND REGARDING THE CODE.  THIS CODE IS
-* LICENSED ON AN "AS IS" BASIS AND INTEL WILL NOT PROVIDE ANY SUPPORT,
-* ASSISTANCE, INSTALLATION, TRAINING OR OTHER SERVICES.  INTEL DOES NOT
-* PROVIDE ANY UPDATES, ENHANCEMENTS OR EXTENSIONS.  INTEL SPECIFICALLY
-* DISCLAIMS ANY WARRANTY OF MERCHANTABILITY, NONINFRINGEMENT, FITNESS FOR ANY
-* PARTICULAR PURPOSE, OR ANY OTHER WARRANTY.  Intel disclaims all liability,
-* including liability for infringement of any proprietary rights, relating to
-* use of the code. No license, express or implied, by estoppel or otherwise,
-* to any intellectual property rights is granted herein.
-*
-*
-* File Name  : vphal_render_16alignment.cpp
-*
-* Abstract   : Video Surface 16 bytes alignment for Video Processing
-*
-* Environment: ubuntu
-*
-* Notes      : This module contains video surface 16 bytes alignment definitions
-*              for VPHAL
+* The above copyright notice and this permission notice shall be included
+* in all copies or substantial portions of the Software.
 *
+* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+* OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+* THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+* OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+* ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+* OTHER DEALINGS IN THE SOFTWARE.
 */
 //!
 //! \file     vphal_render_16alignment.cpp
@@ -154,7 +150,7 @@ MOS_STATUS VpHal_16AlignLoadStaticData(
             eStatus = MOS_STATUS_INVALID_PARAMETER;
             break;
     }
-#if defined(LINUX)
+#if defined(LINUX) && !defined(WDDM_LINUX)
     WalkerStatic.DW10.Output_Pitch            = p16AlignState->pTarget->OsResource.iPitch;
     WalkerStatic.DW10.Output_Height           = p16AlignState->pTarget->OsResource.iHeight;
 #endif
@@ -247,7 +243,7 @@ MOS_STATUS VpHal_16AlignSetupKernel(
 
     VPHAL_RENDER_CHK_NULL(p16AlignState);
     eStatus             = MOS_STATUS_SUCCESS;
-    pCacheEntryTable    = 
+    pCacheEntryTable    =
         p16AlignState->pKernelDllState->ComponentKernelCache.pCacheEntries;
 
     // Set the Kernel Parameters
@@ -377,7 +373,8 @@ static MOS_STATUS VpHal_16AlignSamplerAvsCalcScalingTable(
                 SrcFormat,
                 fHPStrength,
                 true,
-                dwHwPhrase));
+                dwHwPhrase,
+                0));
 
             // If the 8-tap adaptive is enabled for all channel, then UV/RB use the same coefficient as Y/G
             // So, coefficient for UV/RB channels caculation can be passed
@@ -392,7 +389,8 @@ static MOS_STATUS VpHal_16AlignSamplerAvsCalcScalingTable(
                         SrcFormat,
                         fHPStrength,
                         true,
-                        dwHwPhrase));
+                        dwHwPhrase,
+                        0));
                 }
                 else
                 {
@@ -705,7 +703,7 @@ MOS_STATUS VpHal_16AlignSetupHwStates(
         &MhwKernelParam,
         nullptr);
 
-    if (iKrnAllocation < 0) 
+    if (iKrnAllocation < 0)
     {
         eStatus = MOS_STATUS_UNKNOWN;
         goto finish;
@@ -720,8 +718,8 @@ MOS_STATUS VpHal_16AlignSetupHwStates(
         (pRenderData->pKernelParam->CURBE_Length << 5),
         0,
         nullptr);
-    
-    if (pRenderData->iMediaID < 0) 
+
+    if (pRenderData->iMediaID < 0)
     {
         eStatus = MOS_STATUS_UNKNOWN;
         goto finish;
@@ -729,7 +727,7 @@ MOS_STATUS VpHal_16AlignSetupHwStates(
 
     // Set Sampler states for this Media ID
     VPHAL_RENDER_CHK_STATUS(p16AlignState->pfnSetSamplerStates(
-        p16AlignState, 
+        p16AlignState,
         pRenderData));
 
 finish:
@@ -750,7 +748,7 @@ finish:
 //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
 //!
 MOS_STATUS VpHal_16AlignRenderMediaWalker(
-    PVPHAL_16_ALIGN_STATE        p16AlignState,    
+    PVPHAL_16_ALIGN_STATE        p16AlignState,
     PVPHAL_16_ALIGN_RENDER_DATA  pRenderData,
     PMHW_WALKER_PARAMS               pWalkerParams)
 {
@@ -780,10 +778,10 @@ MOS_STATUS VpHal_16AlignRenderMediaWalker(
 
     pWalkerParams->dwGlobalLoopExecCount        = 1;
     pWalkerParams->dwLocalLoopExecCount         = pRenderData->iBlocksY - 1;
-    
+
     pWalkerParams->GlobalResolution.x           = pRenderData->iBlocksX;
     pWalkerParams->GlobalResolution.y           = pRenderData->iBlocksY;
-    
+
     pWalkerParams->GlobalStart.x                = 0;
     pWalkerParams->GlobalStart.y                = 0;
 
@@ -795,7 +793,7 @@ MOS_STATUS VpHal_16AlignRenderMediaWalker(
 
     pWalkerParams->BlockResolution.x            = pRenderData->iBlocksX;
     pWalkerParams->BlockResolution.y            = pRenderData->iBlocksY;
-   
+
     pWalkerParams->LocalStart.x                 = 0;
     pWalkerParams->LocalStart.y                 = 0;
 
@@ -807,7 +805,7 @@ MOS_STATUS VpHal_16AlignRenderMediaWalker(
 
     pWalkerParams->LocalInnerLoopUnit.x         = 1;
     pWalkerParams->LocalInnerLoopUnit.y         = 0;
-    
+
     return eStatus;
 }
 
@@ -857,7 +855,7 @@ MOS_STATUS VpHal_16AlignRender(
 
     VPHAL_DBG_STATE_DUMPPER_SET_CURRENT_STAGE(VPHAL_DBG_STAGE_COMP);
 
-    // Configure cache settings for this render operation 
+    // Configure cache settings for this render operation
     pCacheSettings      = &pRenderHal->L3CacheSettings;
     MOS_ZeroMemory(pCacheSettings, sizeof(*pCacheSettings));
     pCacheSettings->bOverride                  = true;
@@ -905,14 +903,14 @@ MOS_STATUS VpHal_16AlignRender(
 
     // Ensure input can be read
     pOsInterface->pfnSyncOnResource(
-        pOsInterface, 
+        pOsInterface,
         &p16AlignState->pSource->OsResource,
         pOsInterface->CurrentGpuContextOrdinal,
         false);
 
     // Ensure the output can be written
     pOsInterface->pfnSyncOnResource(
-        pOsInterface, 
+        pOsInterface,
         &p16AlignState->pTarget->OsResource,
         pOsInterface->CurrentGpuContextOrdinal,
         true);
@@ -924,7 +922,7 @@ MOS_STATUS VpHal_16AlignRender(
 
     // Submit HW States and Commands
     VPHAL_RENDER_CHK_STATUS(VpHal_16AlignSetupHwStates(
-            p16AlignState, 
+            p16AlignState,
             &RenderData));
 
     // Set perftag information
@@ -932,7 +930,7 @@ MOS_STATUS VpHal_16AlignRender(
     pOsInterface->pfnSetPerfTag(pOsInterface, RenderData.PerfTag);
 
     VPHAL_RENDER_CHK_STATUS(VpHal_16AlignRenderMediaWalker(
-            p16AlignState,    
+            p16AlignState,
             &RenderData,
             &WalkerParams));
 
@@ -940,7 +938,7 @@ MOS_STATUS VpHal_16AlignRender(
     VPHAL_DBG_STATE_DUMPPER_DUMP_SSH(pRenderHal);
 
     VPHAL_RENDER_CHK_STATUS(VpHal_RndrSubmitCommands(
-        pRenderHal, 
+        pRenderHal,
         nullptr,
         p16AlignState->bNullHwRender16Align,
         &WalkerParams,
@@ -1001,7 +999,7 @@ MOS_STATUS VpHal_16AlignInitialize(
     VPHAL_RENDER_ASSERT(p16AlignState);
     VPHAL_RENDER_ASSERT(p16AlignState->pOsInterface);
 
-    NullRenderingFlags            = 
+    NullRenderingFlags            =
                     p16AlignState->pOsInterface->pfnGetNullHWRenderFlags(p16AlignState->pOsInterface);
     p16AlignState->bNullHwRender16Align =
                     NullRenderingFlags.VPLgca ||
@@ -1047,7 +1045,7 @@ MOS_STATUS VpHal_16AlignSetupSurfaceStatesInt(
     PRENDERHAL_SURFACE_STATE_ENTRY      pSurfaceEntry;
     MOS_FORMAT                          format  = pSurface->Format;
     uint32_t                            width   = pSurface->dwWidth;
-#if defined(LINUX)
+#if defined(LINUX) && !defined(WDDM_LINUX)
     uint32_t                            dwSize  = pSurface->dwHeight * pSurface->OsResource.iPitch;
 #else
     uint32_t                            dwSize  = pSurface->dwHeight * pSurface->dwPitch;
@@ -1201,7 +1199,7 @@ MOS_STATUS VpHal_16AlignSetupSurfaceStates(
         SurfaceParams.bAVS          = true;
     }
     SurfaceParams.Boundary          = RENDERHAL_SS_BOUNDARY_SRCRECT;
-    SurfaceParams.bRenderTarget     = false;
+    SurfaceParams.isOutput     = false;
     SurfaceParams.MemObjCtl         =
         p16AlignState->SurfMemObjCtl.SourceSurfMemObjCtl;
     SurfaceParams.Type              = RENDERHAL_SURFACE_TYPE_ADV_G9;
@@ -1220,7 +1218,7 @@ MOS_STATUS VpHal_16AlignSetupSurfaceStates(
     SurfaceParams.MemObjCtl         =
         p16AlignState->SurfMemObjCtl.TargetSurfMemObjCtl;
     SurfaceParams.Type              = pRenderHal->SurfaceTypeDefault;
-    SurfaceParams.bRenderTarget     = true;
+    SurfaceParams.isOutput     = true;
     SurfaceParams.bAVS              = false;
     SurfaceParams.Boundary          = RENDERHAL_SS_BOUNDARY_DSTRECT;
 
@@ -1268,7 +1266,7 @@ MOS_STATUS VpHal_16AlignInitInterface(
     p16AlignState->pfnSetupSurfaceStates = VpHal_16AlignSetupSurfaceStates;
 
     // States
-    p16AlignState->bFtrMediaWalker       = 
+    p16AlignState->bFtrMediaWalker       =
         p16AlignState->pRenderHal->pfnGetMediaWalkerStatus(p16AlignState->pRenderHal) ? true : false;
 
     p16AlignState->pfnLoadStaticData     = VpHal_16AlignLoadStaticData;
