@@ -363,7 +363,7 @@ MOS_STATUS CodechalDecodeVc1G12::DecodeStateLevel()
                     &dstSurface));
 
                 m_debugInterface->m_refIndex = (uint16_t)i;
-                std::string refSurfName      = "RefSurf" + std::to_string(static_cast<uint32_t>(m_debugInterface->m_refIndex));
+                std::string refSurfName      = "RefSurf[" + std::to_string(static_cast<uint32_t>(m_debugInterface->m_refIndex)) + "]";
                 CODECHAL_DECODE_CHK_STATUS_RETURN(m_debugInterface->DumpYUVSurface(
                     &dstSurface,
                     CodechalDbgAttr::attrDecodeReferenceSurfaces,
