@@ -49,6 +49,9 @@ MOS_STATUS CodechalEncodeCscDsG12::AllocateSurfaceCsc()
 
     CODECHAL_ENCODE_CHK_STATUS_RETURN(CodechalEncodeCscDs::AllocateSurfaceCsc());
 
+    MEDIA_WA_TABLE* waTable = m_osInterface->pfnGetWaTable(m_osInterface);
+    uint32_t memType = (MEDIA_IS_WA(waTable, WaForceAllocateLML4)) ? MOS_MEMPOOL_DEVICEMEMORY : 0;
+
     // allocate the MbStats surface
     if (Mos_ResourceIsNull(&m_resMbStatsBuffer))
     {
@@ -62,6 +65,7 @@ MOS_STATUS CodechalEncodeCscDsG12::AllocateSurfaceCsc()
         allocParamsForBufferLinear.dwBytes = m_hwInterface->m_avcMbStatBufferSize =
             MOS_ALIGN_CEIL((alignedWidth * alignedHeight << 6) , 1024);
         allocParamsForBufferLinear.pBufName = "MB Statistics Buffer";
+        allocParamsForBufferLinear.dwMemType = memType;
 
         CODECHAL_ENCODE_CHK_STATUS_MESSAGE_RETURN(m_osInterface->pfnAllocateResource(
             m_osInterface,
@@ -92,11 +96,13 @@ MOS_STATUS CodechalEncodeCscDsG12::CheckRawColorFormat(MOS_FORMAT format, MOS_TI
         m_cscRequireConvTo8bPlanar = (uint8_t)HCP_CHROMA_FORMAT_YUV422 == m_outputChromaFormat;
         break;
     case Format_A8R8G8B8:
+    case Format_X8R8G8B8:
         m_colorRawSurface = cscColorARGB;
         m_cscUsingSfc = IsSfcEnabled() ? 1 : 0;
         m_cscRequireColor = 1;
         //Use EU for better performance in big resolution cases
-        if (m_cscRawSurfWidth * m_cscRawSurfHeight > 1920 * 1088)
+        if (m_cscRawSurfWidth * m_cscRawSurfHeight > 1920 * 1088
+            && !MEDIA_IS_WA(m_hwInterface->GetWaTable(), Wa_1409932735))
         {
             m_cscUsingSfc = 0;
         }
@@ -135,25 +141,26 @@ MOS_STATUS CodechalEncodeCscDsG12::CheckRawColorFormat(MOS_FORMAT format, MOS_TI
         m_cscRequireConvTo8bPlanar = 1;
         break;
     case Format_AYUV:
-        if(m_encoder->m_vdencEnabled)
+        if (m_encoder->m_vdencEnabled)
         {
             m_colorRawSurface = cscColorAYUV;
+            m_cscRequireColor = 1;
             break;
         }
     case Format_R10G10B10A2:
-        if(m_encoder->m_vdencEnabled)
+        if (m_encoder->m_vdencEnabled)
         {
             m_colorRawSurface = cscColorARGB10;
             break;
         }
     case Format_B10G10R10A2:
-        if(m_encoder->m_vdencEnabled)
+        if (m_encoder->m_vdencEnabled)
         {
             m_colorRawSurface = cscColorABGR10;
             break;
         }
     case Format_Y410:
-        if(m_encoder->m_vdencEnabled)
+        if (m_encoder->m_vdencEnabled)
         {
             m_colorRawSurface = cscColorY410;
             break;
@@ -290,7 +297,7 @@ MOS_STATUS CodechalEncodeCscDsG12::SetKernelParamsCsc(KernelParams* params)
     }
     else
     {
-        // do 16x/32x downscaling      
+        // do 16x/32x downscaling
         m_curbeParams.bConvertFlag = false;
         mbStatsSurface = nullptr;
 
@@ -301,7 +308,7 @@ MOS_STATUS CodechalEncodeCscDsG12::SetKernelParamsCsc(KernelParams* params)
             m_curbeParams.downscaleStage = dsStage16x;
             inputFrameWidth = m_encoder->m_downscaledWidth4x << 2;
             inputFrameHeight = m_encoder->m_downscaledHeight4x << 2;
-            
+
             inputSurface = m_encoder->m_trackedBuf->Get4xDsSurface(CODEC_CURR_TRACKED_BUFFER);
             output4xDsSurface = m_encoder->m_trackedBuf->Get16xDsSurface(CODEC_CURR_TRACKED_BUFFER);
             output2xDsSurface = nullptr;
@@ -387,13 +394,6 @@ MOS_STATUS CodechalEncodeCscDsG12::SetCurbeCsc()
     curbe.DW2_OriginalPicWidthInSamples = m_curbeParams.dwInputPictureWidth;
     curbe.DW2_OriginalPicHeightInSamples = m_curbeParams.dwInputPictureHeight;
 
-    // when the input surface is NV12 tiled format and not aligned with 4 bytes,
-    // need kernel to do the padding copy with force to linear format, it's
-    // transparent to kernel and hw can handle it
-    if (m_colorRawSurface == cscColorNv12TileY && m_cscFlag == 1)
-        curbe.DW1_PictureFormat = cscColorNv12Linear;
-
-
     // RGB->YUV CSC coefficients
     if (m_curbeParams.inputColorSpace == ECOLORSPACE_P709)
     {
@@ -513,17 +513,13 @@ MOS_STATUS CodechalEncodeCscDsG12::SendSurfaceCsc(PMOS_COMMAND_BUFFER cmdBuffer)
                                                    cscColorNv12Linear == m_colorRawSurface);
     }
 
-    if(m_encoder->m_vdencEnabled && CODECHAL_HEVC == m_standard)
+    if (m_encoder->m_vdencEnabled && (CODECHAL_HEVC == m_standard || CODECHAL_AVC == m_standard))
     {
         surfaceParams.bCheckCSC8Format= true;
     }
 
-    // when input surface is NV12 tiled and not aligned by 4 bytes, need kernel to do the
-    // padding copy by forcing to linear format and set the HeightInUse as Linear format
-    // kernel will use this info to calucate UV offset
     surfaceParams.psSurface = m_surfaceParamsCsc.psInputSurface;
-    if (cscColorNv12Linear == m_colorRawSurface ||
-        (cscColorNv12TileY == m_colorRawSurface && m_cscFlag == 1))
+    if (cscColorNv12Linear == m_colorRawSurface)
     {
         surfaceParams.dwHeightInUse = (surfaceParams.psSurface->dwHeight * 3) / 2;
     }
@@ -534,6 +530,14 @@ MOS_STATUS CodechalEncodeCscDsG12::SendSurfaceCsc(PMOS_COMMAND_BUFFER cmdBuffer)
 #ifdef _MMC_SUPPORTED
     CODECHAL_ENCODE_CHK_NULL_RETURN(m_encoder->m_mmcState);
     CODECHAL_ENCODE_CHK_STATUS_RETURN(m_encoder->m_mmcState->SetSurfaceParams(&surfaceParams));
+
+    // disable compression for render RC TA resources
+    if (surfaceParams.psSurface->MmcState == MOS_MEMCOMP_RC &&
+        surfaceParams.psSurface->OsResource.pGmmResInfo->GetArraySize() > 1)
+    {
+        CODECHAL_ENCODE_CHK_STATUS_RETURN(m_osInterface->pfnDecompResource(m_osInterface, &surfaceParams.psSurface->OsResource));
+        surfaceParams.psSurface->MmcState = MOS_MEMCOMP_DISABLED;
+    }
 #endif
 
     surfaceParams.dwBindingTableOffset = cscSrcYPlane;
@@ -855,6 +859,32 @@ MOS_STATUS CodechalEncodeCscDsG12::InitSfcState()
     return MOS_STATUS_SUCCESS;
 }
 
+MOS_STATUS CodechalEncodeCscDsG12::SurfaceNeedsExtraCopy()
+{
+    m_needsExtraCopy = true;
+    return MOS_STATUS_SUCCESS;
+}
+
+MOS_STATUS CodechalEncodeCscDsG12::CheckRawSurfaceAlignment(MOS_SURFACE surface)
+{
+    if (m_cscEnableCopy && m_needsExtraCopy)
+    {
+        if (surface.Format == Format_A8R8G8B8) // not touch NV12 logic.
+        {
+            m_colorRawSurface = cscColorARGB;
+            m_cscRequireCopy = 1;
+        }
+    }
+
+    if (m_cscEnableCopy && (surface.dwWidth % m_rawSurfAlignment || surface.dwHeight % m_rawSurfAlignment) &&
+        m_colorRawSurface != cscColorNv12TileY)
+    {
+        m_cscRequireCopy = 1;
+    }
+
+    return MOS_STATUS_SUCCESS;
+}
+
 CodechalEncodeCscDsG12::CodechalEncodeCscDsG12(CodechalEncoderState* encoder)
     : CodechalEncodeCscDs(encoder)
 {
