@@ -30,40 +30,38 @@
 #include "igcodeckrn_g11.h"
 #endif
 
-extern template class MediaInterfacesFactory<MhwInterfaces>;
-extern template class MediaInterfacesFactory<MmdDevice>;
-extern template class MediaInterfacesFactory<MosUtilDevice>;
-extern template class MediaInterfacesFactory<CodechalDevice>;
+extern template class MediaFactory<uint32_t, MhwInterfaces>;
+extern template class MediaFactory<uint32_t, MmdDevice>;
+extern template class MediaFactory<uint32_t, CodechalDevice>;
 
-extern template class MediaInterfacesFactory<CMHalDevice>;
+extern template class MediaFactory<uint32_t, CMHalDevice>;
 
-extern template class MediaInterfacesFactory<VphalDevice>;
-extern template class MediaInterfacesFactory<RenderHalDevice>;
-extern template class MediaInterfacesFactory<Nv12ToP010Device>;
-extern template class MediaInterfacesFactory<DecodeHistogramDevice>;
+extern template class MediaFactory<uint32_t, VphalDevice>;
+extern template class MediaFactory<uint32_t, RenderHalDevice>;
+extern template class MediaFactory<uint32_t, Nv12ToP010Device>;
+extern template class MediaFactory<uint32_t, DecodeHistogramDevice>;
 
 static bool icllpRegisteredVphal =
-MediaInterfacesFactory<VphalDevice>::
-RegisterHal<VphalInterfacesG11Icllp>((uint32_t)IGFX_ICELAKE_LP);
+MediaFactory<uint32_t, VphalDevice>::
+Register<VphalInterfacesG11Icllp>((uint32_t)IGFX_ICELAKE_LP);
 
 MOS_STATUS VphalInterfacesG11Icllp::Initialize(
     PMOS_INTERFACE  osInterface,
-    PMOS_CONTEXT    osDriverContext,
     bool            bInitVphalState,
-    MOS_STATUS      *eStatus)
+    MOS_STATUS      *eStatus,
+    bool            clearViewMode)
 {
-    m_vphalState = MOS_New(
+    m_vpBase = MOS_New(
         VphalState,
         osInterface,
-        osDriverContext,
         eStatus);
 
     return *eStatus;
 }
 
 static bool icllpRegisteredMhw =
-    MediaInterfacesFactory<MhwInterfaces>::
-    RegisterHal<MhwInterfacesG11Icllp>((uint32_t)IGFX_ICELAKE_LP);
+    MediaFactory<uint32_t, MhwInterfaces>::
+    Register<MhwInterfacesG11Icllp>((uint32_t)IGFX_ICELAKE_LP);
 
 #define PLATFORM_INTEL_ICLLP 13
 #define GENX_ICLLP           10
@@ -93,7 +91,7 @@ MOS_STATUS MhwInterfacesG11Icllp::Initialize(
 
     // MHW_CP and MHW_MI must always be created
     MOS_STATUS status = MOS_STATUS_SUCCESS;
-    m_cpInterface = Create_MhwCpInterface(osInterface);
+    m_cpInterface = osInterface->pfnCreateMhwCpInterface(osInterface);
     if(m_cpInterface == nullptr)
     {
         MOS_OS_ASSERTMESSAGE("new osInterface failed");
@@ -204,8 +202,8 @@ finish:
 
 #ifdef _MMC_SUPPORTED
 static bool icllpRegisteredMmd =
-    MediaInterfacesFactory<MmdDevice>::
-    RegisterHal<MmdDeviceG11Icllp>((uint32_t)IGFX_ICELAKE_LP);
+    MediaFactory<uint32_t, MmdDevice>::
+    Register<MmdDeviceG11Icllp>((uint32_t)IGFX_ICELAKE_LP);
 
 MOS_STATUS MmdDeviceG11Icllp::Initialize(
     PMOS_INTERFACE osInterface,
@@ -259,8 +257,8 @@ MOS_STATUS MmdDeviceG11Icllp::Initialize(
 }
 #endif
 static bool icllpRegisteredNv12ToP010 =
-    MediaInterfacesFactory<Nv12ToP010Device>::
-    RegisterHal<Nv12ToP010DeviceG11Icllp>((uint32_t)IGFX_ICELAKE_LP);
+    MediaFactory<uint32_t, Nv12ToP010Device>::
+    Register<Nv12ToP010DeviceG11Icllp>((uint32_t)IGFX_ICELAKE_LP);
 
 MOS_STATUS Nv12ToP010DeviceG11Icllp::Initialize(
     PMOS_INTERFACE            osInterface)
@@ -271,8 +269,8 @@ MOS_STATUS Nv12ToP010DeviceG11Icllp::Initialize(
 }
 
 static bool icllpRegisteredCodecHal =
-    MediaInterfacesFactory<CodechalDevice>::
-    RegisterHal<CodechalInterfacesG11Icllp>((uint32_t)IGFX_ICELAKE_LP);
+    MediaFactory<uint32_t, CodechalDevice>::
+    Register<CodechalInterfacesG11Icllp>((uint32_t)IGFX_ICELAKE_LP);
 
 MOS_STATUS CodechalInterfacesG11Icllp::Initialize(
     void *standardInfo,
@@ -578,8 +576,8 @@ MOS_STATUS CodechalInterfacesG11Icllp::Initialize(
 
 #if !__BSD__
 static bool icllpRegisteredCMHal =
-    MediaInterfacesFactory<CMHalDevice>::
-    RegisterHal<CMHalInterfacesG11Icllp>((uint32_t)IGFX_ICELAKE_LP);
+    MediaFactory<uint32_t, CMHalDevice>::
+    Register<CMHalInterfacesG11Icllp>((uint32_t)IGFX_ICELAKE_LP);
 
 MOS_STATUS CMHalInterfacesG11Icllp::Initialize(CM_HAL_STATE *pCmState)
 {
@@ -606,43 +604,9 @@ MOS_STATUS CMHalInterfacesG11Icllp::Initialize(CM_HAL_STATE *pCmState)
 }
 #endif
 
-static bool icllpRegisteredMosUtil =
-    MediaInterfacesFactory<MosUtilDevice>::
-    RegisterHal<MosUtilDeviceG11Icllp>((uint32_t)IGFX_ICELAKE_LP);
-
-MOS_STATUS MosUtilDeviceG11Icllp::Initialize()
-{
-#define MOSUTIL_FAILURE()                                       \
-{                                                           \
-    if (device != nullptr)                                  \
-    {                                                       \
-        delete device;                                      \
-    }                                                       \
-    return MOS_STATUS_NO_SPACE;                             \
-}
-
-    MosUtil *device = nullptr;
-
-    device = MOS_New(MosUtil);
-
-    if (device == nullptr)
-    {
-        MOSUTIL_FAILURE();
-    }
-
-    if (device->Initialize() != MOS_STATUS_SUCCESS)
-    {
-        MOSUTIL_FAILURE();
-    }
-
-    m_mosUtilDevice = device;
-
-    return MOS_STATUS_SUCCESS;
-}
-
 static bool icllpRegisteredRenderHal =
-    MediaInterfacesFactory<RenderHalDevice>::
-    RegisterHal<RenderHalInterfacesG11Icllp>((uint32_t)IGFX_ICELAKE_LP);
+    MediaFactory<uint32_t, RenderHalDevice>::
+    Register<RenderHalInterfacesG11Icllp>((uint32_t)IGFX_ICELAKE_LP);
 
 MOS_STATUS RenderHalInterfacesG11Icllp::Initialize()
 {
@@ -656,8 +620,8 @@ MOS_STATUS RenderHalInterfacesG11Icllp::Initialize()
 }
 
 static bool icllpRegisteredDecodeHistogram =
-MediaInterfacesFactory<DecodeHistogramDevice>::
-RegisterHal<DecodeHistogramDeviceG11Icllp>((uint32_t)IGFX_ICELAKE_LP);
+MediaFactory<uint32_t, DecodeHistogramDevice>::
+Register<DecodeHistogramDeviceG11Icllp>((uint32_t)IGFX_ICELAKE_LP);
 
 MOS_STATUS DecodeHistogramDeviceG11Icllp::Initialize(
     CodechalHwInterface       *hwInterface,
@@ -676,7 +640,7 @@ MOS_STATUS DecodeHistogramDeviceG11Icllp::Initialize(
 
 #define IP_VERSION_M11_0       0x1100
 static bool iclRegisteredHwInfo =
-    MediaInterfacesFactory<MediaInterfacesHwInfoDevice>::RegisterHal<MediaInterfacesHwInfoDeviceG11Icllp>((uint32_t)IGFX_ICELAKE_LP);
+    MediaFactory<uint32_t, MediaInterfacesHwInfoDevice>::Register<MediaInterfacesHwInfoDeviceG11Icllp>((uint32_t)IGFX_ICELAKE_LP);
 
 MOS_STATUS MediaInterfacesHwInfoDeviceG11Icllp::Initialize(PLATFORM platform)
 {
