@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020-2022, Intel Corporation
+* Copyright (c) 2020-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -491,6 +491,8 @@ MHW_SETPAR_DECL_SRC(MFX_AVC_DIRECTMODE_STATE, AvcDecodePicPkt)
     params.avcRefList              = (void **)refFrames.m_refList;
     params.bPicIdRemappingInUse    = m_avcBasicFeature->m_picIdRemappingInUse;
 
+    CODECHAL_DEBUG_TOOL(DECODE_CHK_STATUS(DumpResources(curMvBuffer->size)));
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -591,7 +593,7 @@ MOS_STATUS AvcDecodePicPkt::AddAllCmds_MFX_QM_STATE(PMOS_COMMAND_BUFFER cmdBuffe
             qMatrix[i * 16 + ii] = iqMatrix->List4x4[i][ii];
         }
     }
-    m_mfxItf->MHW_ADDCMD_F(MFX_QM_STATE)(cmdBuffer);
+    DECODE_CHK_STATUS(m_mfxItf->MHW_ADDCMD_F(MFX_QM_STATE)(cmdBuffer));
 
     params.qmType = m_avcBasicFeature->avcQmInter4x4;
     for (auto i = 3; i < 6; i++)
@@ -601,33 +603,35 @@ MOS_STATUS AvcDecodePicPkt::AddAllCmds_MFX_QM_STATE(PMOS_COMMAND_BUFFER cmdBuffe
             qMatrix[(i - 3) * 16 + ii] = iqMatrix->List4x4[i][ii];
         }
     }
-    m_mfxItf->MHW_ADDCMD_F(MFX_QM_STATE)(cmdBuffer);
+    DECODE_CHK_STATUS(m_mfxItf->MHW_ADDCMD_F(MFX_QM_STATE)(cmdBuffer));
 
     params.qmType = m_avcBasicFeature->avcQmIntra8x8;
     for (auto ii = 0; ii < 64; ii++)
     {
         qMatrix[ii] = iqMatrix->List8x8[0][ii];
     }
-    m_mfxItf->MHW_ADDCMD_F(MFX_QM_STATE)(cmdBuffer);
+    DECODE_CHK_STATUS(m_mfxItf->MHW_ADDCMD_F(MFX_QM_STATE)(cmdBuffer));
 
     params.qmType = m_avcBasicFeature->avcQmInter8x8;
     for (auto ii = 0; ii < 64; ii++)
     {
         qMatrix[ii] = iqMatrix->List8x8[1][ii];
     }
-    m_mfxItf->MHW_ADDCMD_F(MFX_QM_STATE)(cmdBuffer);
+    DECODE_CHK_STATUS(m_mfxItf->MHW_ADDCMD_F(MFX_QM_STATE)(cmdBuffer));
 
     return MOS_STATUS_SUCCESS;
 }
 
 #if USE_CODECHAL_DEBUG_TOOL
-MOS_STATUS AvcDecodePicPkt::DumpResources() const
+MOS_STATUS AvcDecodePicPkt::DumpResources(uint32_t mvBufferSize) const
 {
     DECODE_FUNC_CALL();
 
     CodechalDebugInterface *debugInterface = m_avcPipeline->GetDebugInterface();
 
     auto &par = m_mfxItf->MHW_GETPAR_F(MFX_PIPE_BUF_ADDR_STATE)();
+    auto &mvParam = m_mfxItf->MHW_GETPAR_F(MFX_AVC_DIRECTMODE_STATE)();
+
     for (auto n = 0; n < CODEC_AVC_MAX_NUM_REF_FRAME; n++)
     {
         if (m_avcBasicFeature->m_refFrames.m_avcPicIdx[n].bValid)
@@ -641,9 +645,22 @@ MOS_STATUS AvcDecodePicPkt::DumpResources() const
                 &destSurface,
                 CodechalDbgAttr::attrDecodeReferenceSurfaces,
                 refSurfName.c_str()));
+
+            std::string mvBufDumpName = "_DEC_Ref_MV_" + std::to_string(n);
+            DECODE_CHK_STATUS(debugInterface->DumpBuffer(
+                &mvParam.presAvcDmvBuffers[n+1],
+                CodechalDbgAttr::attrMvData,
+                mvBufDumpName.c_str(),
+                mvBufferSize));
         }
     }
 
+    DECODE_CHK_STATUS(debugInterface->DumpBuffer(
+        &mvParam.presAvcDmvBuffers[0],
+        CodechalDbgAttr::attrMvData,
+        "DEC_Cur_MV_",
+        mvBufferSize));
+
     return MOS_STATUS_SUCCESS;
 }
 #endif
@@ -676,4 +693,4 @@ MOS_STATUS AvcDecodePicPkt::SetSurfaceMmcState() const
     return MOS_STATUS_SUCCESS;
 }
 
-}  // namespace decode
\ No newline at end of file
+}  // namespace decode
