@@ -239,7 +239,12 @@ MOS_STATUS HevcPipeline::CreatePhase(uint8_t pass, uint8_t pipe, uint8_t activeP
     DECODE_FUNC_CALL();
     T *phase = MOS_New(T, *this, m_scalabOption);
     DECODE_CHK_NULL(phase);
-    DECODE_CHK_STATUS(phase->Initialize(pass, pipe, activePipeNum));
+    MOS_STATUS estatus = phase->Initialize(pass, pipe, activePipeNum);
+    if (estatus != MOS_STATUS_SUCCESS)
+    {
+        MOS_Delete(phase);
+        return estatus;
+    }
     m_phaseList.push_back(phase);
     return MOS_STATUS_SUCCESS;
 }
@@ -499,7 +504,7 @@ MOS_STATUS HevcPipeline::DumpSliceParams(
             if (shortFormatInUse)
             {
                 PCODEC_HEVC_SF_SLICE_PARAMS slcParamsSF =
-                    (PCODEC_HEVC_SF_SLICE_PARAMS)MOS_AllocMemory(sizeof(PCODEC_HEVC_SF_SLICE_PARAMS) * numSlices);
+                    (PCODEC_HEVC_SF_SLICE_PARAMS)MOS_AllocMemory(sizeof(CODEC_HEVC_SF_SLICE_PARAMS) * numSlices);
 
                 for (uint16_t i = 0; i < numSlices; i++)
                 {
