@@ -139,7 +139,7 @@ struct _MHW_PAR_T(MFX_PIPE_MODE_SELECT)
     bool     shortFormatInUse                               = false;
     bool     vc1OddFrameHeight                              = false;
     uint32_t mediaSoftResetCounterPer1000Clocks             = 0;
-    bool     streamOutEnabled                               = false;
+    bool     sliceSizeStreamout32bit                        = false;
 };
 
 struct _MHW_PAR_T(MFX_SURFACE_STATE)
@@ -287,8 +287,9 @@ struct _MHW_PAR_T(MFX_AVC_IMG_STATE)
     uint32_t                  numMBs                                       = 0;
     uint32_t                  imgStructImageStructureImgStructure10        = 0;
     uint32_t                  interViewOrderDisable                        = 0;
-    
-    __MHW_VDBOX_MFX_WRAPPER_EXT(MFX_AVC_IMG_STATE_CMDPAR_EXT);
+    bool                      vdaqmEnable                                  = false;  
+    uint8_t                   bitDepthLumaMinus8                           = 0;                
+    uint8_t                   bitDepthChromaMinus8                         = 0;
 };
 
 struct _MHW_PAR_T(MFX_AVC_REF_IDX_STATE)
@@ -734,7 +735,7 @@ struct _MHW_PAR_T(MFD_IT_OBJECT)
 
 struct _MHW_PAR_T(MFD_IT_OBJECT_MPEG2_INLINE_DATA)
 {
-    CodecDecodeMpeg2MbParmas *pMBParams = nullptr;
+    CodecDecodeMpeg2MbParams *pMBParams = nullptr;
 
     int32_t CodingType     = 0;
     int16_t sPackedMVs0[4] = {};
