@@ -32,38 +32,19 @@
 #ifndef __MOS_OCA_RTLOG_MGR_H__
 #define __MOS_OCA_RTLOG_MGR_H__
 
-#include "mos_oca_rtlog_mgr_defs.h"
-#include "mos_os_specific.h"
-#include "mos_utilities.h"
-#include <vector>
+#include "mos_oca_rtlog_mgr_base.h"
 
-class OsContextNext;
-class OsContextSpecificNext;
-
-struct MOS_OCA_RTLOG_RES_AND_INTERFACE
-{
-    PMOS_RESOURCE  ocaRTLogResource = nullptr;
-    PMOS_INTERFACE osInterface      = nullptr;
-};
-
-class MosOcaRTLogMgr
+class MosOcaRTLogMgr : public MosOcaRTLogMgrBase
 {
 public:
-    bool IsMgrInitialized() { return m_isMgrInitialized; };
-
-    uint32_t GetRtlogHeapSize() { return m_heapSize; };
-
     static void RegisterContext(OsContextNext *osDriverContext, MOS_CONTEXT *osContext);
-
     static void UnRegisterContext(OsContextNext *osDriverContext);
 
-    static bool IsOcaRTLogEnabled() { return m_enableOcaRTLog; };
-
     MosOcaRTLogMgr();
     MosOcaRTLogMgr(MosOcaRTLogMgr &);
     virtual ~MosOcaRTLogMgr();
     MosOcaRTLogMgr &operator=(MosOcaRTLogMgr &);
-    static MosOcaRTLogMgr &GetInstance();
+    static MosOcaRTLogMgr *GetInstance();
 
 protected:
     virtual MOS_STATUS RegisterCtx(OsContextNext *osDriverContext, MOS_CONTEXT *osContext);
@@ -71,17 +52,8 @@ protected:
     virtual MOS_STATUS RegisterRes(OsContextNext *osDriverContext, MOS_OCA_RTLOG_RES_AND_INTERFACE *resInterface, MOS_CONTEXT *osContext);
     virtual void       UnregisterRes(OsContextNext *osDriverContext);
     virtual MOS_STATUS MapGfxVa(PMOS_RESOURCE ocaRTLogResource, OsContextNext *osDriverContext);
-    int32_t GetGlobleIndex();
 
-    OsContextNext                       *m_osContext = nullptr;
-    int32_t                              m_globleIndex = -1;
-    bool                                 m_isMgrInitialized = false;
     std::map<OsContextNext *, MOS_OCA_RTLOG_RES_AND_INTERFACE> m_resMap;
-    uint32_t                             m_heapSize = MAX_OCA_RT_SIZE;
-    uint8_t                             *m_heapAddr = nullptr;
-
-    static bool                          m_enableOcaRTLog;
-    static MosMutex                      s_ocaMutex;
 
 MEDIA_CLASS_DEFINE_END(MosOcaRTLogMgr)
 };
