@@ -43,12 +43,12 @@ VphdrResourceManager::~VphdrResourceManager()
 }
 
 MOS_STATUS VphdrResourceManager::AssignRenderResource(VP_EXECUTE_CAPS &caps, std::vector<VP_SURFACE *> &inputSurfaces, VP_SURFACE *outputSurface, RESOURCE_ASSIGNMENT_HINT resHint,
-    VP_SURFACE_SETTING &surfSetting, SwFilterPipe &executedFilters, MOS_INTERFACE osInterface, VphalFeatureReport &reporting, bool deferredDestroyed)
+    VP_SURFACE_SETTING &surfSetting, SwFilterPipe &executedFilters, MOS_INTERFACE &osInterface, VphalFeatureReport &reporting, bool deferredDestroyed)
 {
     VP_FUNC_CALL();
 
     bool allocated = false;
-    auto        *skuTable            = MosInterface::GetSkuTable(osInterface.osStreamState);
+    auto        *skuTable            = osInterface.pfnGetSkuTable(&osInterface);
     Mos_MemPool memTypeSurfVideoMem = MOS_MEMPOOL_VIDEOMEMORY;
     uint32_t    dwWidth             = 0;
     uint32_t    dwHeight            = 0;
@@ -133,11 +133,12 @@ MOS_STATUS VphdrResourceManager::AssignRenderResource(VP_EXECUTE_CAPS &caps, std
     dwWidth  = VPHAL_HDR_OETF_1DLUT_WIDTH;
     dwHeight = VPHAL_HDR_OETF_1DLUT_WIDTH;
 
-    for (size_t i = 0; i < VPHAL_MAX_HDR_INPUT_LAYER; ++i)
+    size_t cnt = MOS_MIN(inputSurfaces.size(), VPHAL_MAX_HDR_INPUT_LAYER);
+    for (size_t i = 0; i < cnt; ++i)
     {
         surfSetting.surfGroup.insert(std::make_pair((SurfaceType)(SurfaceTypeHdrInputLayer0 + i), inputSurfaces[i]));
 
-        SwFilterHdr *hdr = dynamic_cast<SwFilterHdr *>(executedFilters.GetSwFilter(true, i, FeatureType::FeatureTypeHdrOnRender));
+        SwFilterHdr    *hdr    = dynamic_cast<SwFilterHdr *>(executedFilters.GetSwFilter(true, i, FeatureType::FeatureTypeHdrOnRender));
         FeatureParamHdr params = {};
         if (hdr)
         {
@@ -172,10 +173,10 @@ MOS_STATUS VphdrResourceManager::AssignRenderResource(VP_EXECUTE_CAPS &caps, std
         surfSetting.surfGroup.insert(std::make_pair((SurfaceType)(SurfaceTypeHdrOETF1DLUTSurface0 + i), m_hdrOETF1DLUTSurface[i]));
     }
 
-    dwWidth = dwHeight = VPHAL_HDR_CRI_3DLUT_SIZE;
+    dwWidth = dwHeight = dwDepth = VPHAL_HDR_CRI_3DLUT_SIZE;
     for (size_t i = 0; i < VPHAL_MAX_HDR_INPUT_LAYER; ++i)
     {
-        SwFilterHdr *hdr = dynamic_cast<SwFilterHdr *>(executedFilters.GetSwFilter(true, i, FeatureType::FeatureTypeHdrOnRender));
+        SwFilterHdr    *hdr    = dynamic_cast<SwFilterHdr *>(executedFilters.GetSwFilter(true, i, FeatureType::FeatureTypeHdrOnRender));
         FeatureParamHdr params = {};
         if (hdr)
         {
@@ -190,7 +191,7 @@ MOS_STATUS VphdrResourceManager::AssignRenderResource(VP_EXECUTE_CAPS &caps, std
              m_hdrCri3DLUTSurface[i],
              "Cri3DLUTSurface",
              params.bGpuGenerate3DLUT ? Format_R10G10B10A2 : Format_A16B16G16R16,
-             MOS_GFXRES_2D,
+             MOS_GFXRES_VOLUME,
              MOS_TILE_LINEAR,
              dwWidth,
              dwHeight,
@@ -199,7 +200,12 @@ MOS_STATUS VphdrResourceManager::AssignRenderResource(VP_EXECUTE_CAPS &caps, std
              allocated,
              false,
              deferredDestroyed,
-             MOS_HW_RESOURCE_USAGE_VP_INTERNAL_READ_RENDER));
+             MOS_HW_RESOURCE_USAGE_VP_INTERNAL_READ_RENDER,
+             MOS_TILE_UNSET_GMM,
+             MOS_MEMPOOL_VIDEOMEMORY,
+             false,
+             nullptr,
+             dwDepth));
 
          surfSetting.Cri3DLUTAllocated = allocated;
          surfSetting.surfGroup.insert(std::make_pair((SurfaceType)(SurfaceTypeHdrCRI3DLUTSurface0 + i), m_hdrCri3DLUTSurface[i]));
@@ -237,6 +243,11 @@ MOS_STATUS VphdrResourceManager::FreeHdrRenderResource()
         {
             m_allocator.DestroyVpSurface(m_hdrOETF1DLUTSurface[i]);
         }
+
+        if (m_hdrCri3DLUTSurface[i])
+        {
+            m_allocator.DestroyVpSurface(m_hdrCri3DLUTSurface[i]);
+        }
     }
 
     return MOS_STATUS_SUCCESS;
