@@ -55,7 +55,9 @@ MOS_STATUS VpFeatureManagerNext::Init(void* settings)
         m_policy = MOS_New(Policy, m_vpInterface);
     }
     VP_PUBLIC_CHK_NULL_RETURN(m_policy);
-
+    vp::VpPlatformInterface *vpPlatformInterface = m_vpInterface.GetHwInterface()->m_vpPlatformInterface;
+    VP_PUBLIC_CHK_NULL_RETURN(vpPlatformInterface);
+    VP_PUBLIC_CHK_STATUS_RETURN(vpPlatformInterface->InitVpFeatureSupportBits());
     VP_PUBLIC_CHK_STATUS_RETURN(RegisterFeatures());
     return m_policy->Initialize();
 }
@@ -190,6 +192,8 @@ MOS_STATUS VpFeatureManagerNext::RegisterFeatures()
     VP_PUBLIC_CHK_NULL_RETURN(p);
     m_featureHandler.insert(std::make_pair(FeatureTypeCgc, p));
 
+    //TODO for AI Feature Developer: Register sw filter handler derived from SwFilterAiBaseHanlder for new AI Feature
+
     m_isFeatureRegistered = true;
     return MOS_STATUS_SUCCESS;
 }
