@@ -27,9 +27,12 @@
 //!
 #include "vp_kernelset.h"
 #include "vp_render_fc_kernel.h"
+#include "vp_render_ocl_fc_kernel.h"
 #include "vp_render_vebox_hdr_3dlut_kernel.h"
 #include "vp_render_vebox_hvs_kernel.h"
 #include "vp_render_hdr_kernel.h"
+#include "vp_render_vebox_hdr_3dlut_ocl_kernel.h"
+#include "vp_render_ai_kernel.h"
 
 using namespace vp;
 
@@ -114,8 +117,9 @@ MOS_STATUS VpKernelSet::FindAndInitKernelObj(VpRenderKernelObj* kernelObj)
 
 MOS_STATUS VpKernelSet::CreateSingleKernelObject(
     VpRenderKernelObj *&kernel,
-    VpKernelID kernelId,
-    KernelIndex kernelIndex)
+    VpKernelID          kernelId,
+    KernelIndex         kernelIndex,
+    std::string         kernelName)
 {
     VP_FUNC_CALL();
     kernel = nullptr;
@@ -125,6 +129,16 @@ MOS_STATUS VpKernelSet::CreateSingleKernelObject(
         kernel = (VpRenderKernelObj*)MOS_New(VpRenderFcKernel, m_hwInterface, m_allocator);
         VP_RENDER_CHK_NULL_RETURN(kernel);
         break;
+    case kernelOclFcCommon:
+    case kernelOclFcFP:
+    case kernelOclFc420PL3Input:
+    case kernelOclFc420PL3Output:
+    case kernelOclFc444PL3Input:
+    case kernelOclFc444PL3Output:
+    case kernelOclFc422HVInput:
+        kernel = (VpRenderKernelObj *)MOS_New(VpRenderOclFcKernel, m_hwInterface, kernelId, kernelIndex, m_allocator);
+        VP_RENDER_CHK_NULL_RETURN(kernel);
+        break;
     case kernelHdr3DLutCalc:
         if (m_pKernelPool->find(VP_HDR_KERNEL_NAME_L0) != m_pKernelPool->end())
         {
@@ -138,6 +152,11 @@ MOS_STATUS VpKernelSet::CreateSingleKernelObject(
         }
         VP_RENDER_CHK_NULL_RETURN(kernel);
         break;
+    case kernelHdr3DLutCalcOcl:
+        VP_RENDER_NORMALMESSAGE("HDR 3dlut kernel use ocl fillLutTable_3dlut kernel");
+        kernel = (VpRenderKernelObj *)MOS_New(VpRenderHdr3DLutOclKernel, m_hwInterface, m_allocator);
+        VP_RENDER_CHK_NULL_RETURN(kernel);
+        break;
     case kernelHVSCalc:
         kernel = (VpRenderKernelObj *)MOS_New(VpRenderHVSKernel, m_hwInterface, kernelId, kernelIndex, m_allocator);
         VP_RENDER_CHK_NULL_RETURN(kernel);
@@ -146,6 +165,10 @@ MOS_STATUS VpKernelSet::CreateSingleKernelObject(
         kernel = (VpRenderKernelObj *)MOS_New(VpRenderHdrKernel, m_hwInterface, m_allocator);
         VP_RENDER_CHK_NULL_RETURN(kernel);
         break;
+    case kernelAiCommon:
+        kernel = (VpRenderKernelObj *)MOS_New(VpRenderAiKernel, m_hwInterface, kernelName, kernelIndex, m_allocator);
+        VP_RENDER_CHK_NULL_RETURN(kernel);
+        break;
     default:
         VP_RENDER_ASSERTMESSAGE("No supported kernel, return");
         return MOS_STATUS_UNIMPLEMENTED;
@@ -194,7 +217,8 @@ MOS_STATUS VpKernelSet::CreateKernelObjects(
             VP_RENDER_CHK_STATUS_RETURN(CreateSingleKernelObject(
                 kernel,
                 kernelParams[kernelIndex].kernelId,
-                kernelIndex));
+                kernelIndex,
+                kernelParams[kernelIndex].kernelName));
             if (kernel->IsKernelCached())
             {
                 m_cachedKernels.insert(std::make_pair(kernelParams[kernelIndex].kernelId, kernel));
