@@ -60,10 +60,11 @@ public:
         uint32_t enabledSFCNv12P010LinearOutput = 0;
         uint32_t enabledSFCRGBPRGB24Output  = 0;
         bool     enableIFNCC                    = false;
-        bool     bEnableL03DLut                 = false;
-        bool     bForceL0FC                     = false;
-        bool     bDisableL0FcFp                 = false;
 #endif
+        VP_CTRL enableOcl3DLut              = VP_CTRL_DEFAULT;
+        VP_CTRL forceOclFC                  = VP_CTRL_DEFAULT;
+        bool    bDisableOclFcFp             = false;
+
         bool disablePacketReuse             = false;
         bool enablePacketReuseTeamsAlways   = false;
 
@@ -75,6 +76,7 @@ public:
         uint32_t           splitFramePortions = 1;
         bool               decompForInterlacedSurfWaEnabled = false;
         bool               enableSFCLinearOutputByTileConvert = false;
+        bool               fallbackScalingToRender8K          = false;
     };
 
     uint32_t Is3DLutKernelOnly()
@@ -108,14 +110,9 @@ public:
         return m_ctrlVal.enableIFNCC;
     }
 
-    bool EnableL03DLut()
+    bool DisableOclFcFp()
     {
-        return m_ctrlVal.bEnableL03DLut;
-    }
-
-    bool DisableL0FcFp()
-    {
-        return m_ctrlVal.bDisableL0FcFp;
+        return m_ctrlVal.bDisableOclFcFp;
     }
 #endif
 
@@ -128,7 +125,9 @@ public:
 
     virtual MOS_STATUS Update(PVP_PIPELINE_PARAMS params);
 
-    bool EnableL0FC();
+    bool EnableOclFC();
+
+    bool EnableOcl3DLut();
 
     bool IsVeboxOutputSurfEnabled()
     {
@@ -210,6 +209,11 @@ public:
         return m_ctrlVal.veboxTypeH;
     }
 
+    bool IsFallbackScalingToRender8K()
+    {
+        return m_ctrlVal.fallbackScalingToRender8K;
+    }
+
     MOS_STATUS SetClearVideoViewMode(bool mode)
     {
         m_ctrlVal.clearVideoViewMode = mode;
